"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../");
class MyProxy extends __1.ServerProxy {
    constructor(app, logger) {
        super(app);
        this.log = logger;
    }
    normalizeError(error) {
        return {
            code: 502,
            body: error.message,
            headers: {},
        };
    }
    normalizeRequest(proxyRequest) {
        const { body, headers, method, path, } = proxyRequest;
        return {
            headers,
            // Convert body to buffer
            body: body !== undefined ? Buffer.from(body) : undefined,
            method,
            path
        };
    }
    normalizeResponse(serverProxyResponse) {
        const { headers, body, statusCode, } = serverProxyResponse;
        return {
            // Convert multi-value headers from Record<string, string[]>
            headers: Object.keys(headers).reduce((result, key) => {
                result[key] = headers[key][0];
                return headers;
            }, {}),
            // Convert body from Buffer to string
            body: body && body.toString(),
            code: statusCode,
        };
    }
}
exports.MyProxy = MyProxy;
exports.sleep = (timeout) => new Promise(resolve => {
    setTimeout(() => resolve(), timeout);
});
exports.loggerMock = () => {
    const logs = [];
    return {
        logs,
        message: (index) => index < 0 ? logs[logs.length + index] : logs[index],
        log: (message) => logs.push(message),
    };
};
